<?php
/***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * Translated to mexican spanish by Francisco Hernandez Odin Consultores Odin.mx
 * All Rights Reserved.
 * 
 * ***********************************************************
*  Module       : Assets
*  Language     : ES Mexico
*  Version      : vt5.4.0
*  Created Date : 2012-02-27
*  Author       : Odin Consultores S de R.L. de C.V.
*  License      : MPL 1.1
 ************************************************************************************/

$mod_strings = Array(
/*some general information*/
'LBL_MODULE_NAME'=>'Activos',
'SINGLE_Assets'=>'Activo',

/*blocks for the module*/
'LBL_ASSET_INFORMATION'=>'Información de Activo',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional',

/*fields for the module*/
'Assets'=>'Activos',
'Asset Name'=>'Nombre Activo',
'Customer Name'=>'Instalado en',
'Product Name'=>'Producto',
'Serial Number'=>'Número serie',
'Asset No'=>'Número Activo',
'Date Sold'=>'Fecha venta',
'Date in Service'=>'Fecha instalación',
'Status'=>'Estado',
'Shipping Method'=>'Forma de envío',
'Shipping Tracking Number'=>'Número seguimiento envío',
'Tag Number'=>'Etiquetado',
'Notes'=>'Notas',
'Invoice Name'=>'Ref. Factura',

/*picklist values*/
'In Service'=>'En Servicio',
'Out-of-service'=>'Fuera de servicio',
'Assets ID'=>'Id de Activo',
);
?>